@@ -5,11 +5,10 @@ from re import compile, MULTILINE
 from types import GeneratorType
 
 from testfixtures import not_there
-from testfixtures.compat import (
-    ClassType, Unicode, basestring, mock_call, unittest_mock_call,
-    PY3)
+from testfixtures.compat import ClassType, Unicode, basestring, PY3
 from testfixtures.resolve import resolve
 from testfixtures.utils import indent
+from testfixtures.mock import parent_name, mock_call, unittest_mock_call
 
 
 def compare_simple(x, y, context):
@@ -20,9 +19,12 @@ def compare_simple(x, y, context):
         return context.label('x', repr(x)) + ' != ' + context.label('y', repr(y))
 
 
-def _extract_attrs(obj):
-    slots = getattr(obj, '__slots__', None)
-    if slots:
+def _extract_attrs(obj, ignore=None):
+    has_slots = getattr(obj, '__slots__', not_there) is not not_there
+    if has_slots:
+        slots = set()
+        for cls in type(obj).__mro__:
+            slots.update(getattr(cls, '__slots__', ()))
         attrs = {}
         for n in slots:
             value = getattr(obj, n, not_there)
@@ -36,17 +38,29 @@ def _extract_attrs(obj):
         else:
             if isinstance(obj, BaseException):
                 attrs['args'] = obj.args
+    if ignore is not None:
+        if isinstance(ignore, dict):
+            ignore = ignore.get(type(obj), ())
+        for attr in ignore:
+            attrs.pop(attr, None)
     return attrs
 
 
 def compare_object(x, y, context):
     """
     Compare the two supplied objects based on their type and attributes.
+
+    :param ignore_attributes:
+
+       Either a sequence of strings containing attribute names to be ignored
+       when comparing or a mapping of type to sequence of strings containing
+       attribute names to be ignored when comparing that type.
     """
+    ignore_attributes = context.get_option('ignore_attributes', ())
     if type(x) is not type(y) or isinstance(x, ClassType):
         return compare_simple(x, y, context)
-    x_attrs = _extract_attrs(x)
-    y_attrs = _extract_attrs(y)
+    x_attrs = _extract_attrs(x, ignore_attributes)
+    y_attrs = _extract_attrs(y, ignore_attributes)
     if x_attrs is None or y_attrs is None:
         return compare_simple(x, y, context)
     if x_attrs != y_attrs:
@@ -317,10 +331,9 @@ def compare_call(x, y, context):
         return
     x_name, x_args, x_kw = x
     y_name, y_args, y_kw = y
-    context.different(x_name, y_name, ' function name')
-    context.different(x_args, y_args, ' args')
-    context.different(x_kw, y_kw, ' kw')
-    return 'mock.call not as expected:'
+    if x_name == y_name and x_args == y_args and x_kw == y_kw:
+        return compare_call(getattr(x, parent_name), getattr(y, parent_name), context)
+    return compare_text(repr(x), repr(y), context)
 
 
 def _short_repr(obj):
@@ -417,10 +430,12 @@ class CompareContext(object):
             possible.append(actual)
 
         if len(possible) != 2:
-            raise TypeError(
-                'Exactly two objects needed, you supplied: ' +
-                repr(possible)
-            )
+            message = 'Exactly two objects needed, you supplied:'
+            if possible:
+                message += ' {}'.format(possible)
+            if self.options:
+                message += ' {}'.format(self.options)
+            raise TypeError(message)
 
         return possible
 
