@@ -1581,3 +1581,74 @@ b
             "datetime.datetime(2001, 1, 1, 0, 0) != "
             "datetime.datetime(2001, 1, 2, 0, 0)"
         )
+
+    def test_inherited_slots(self):
+
+        class Parent(object):
+            __slots__ = ('a',)
+
+        class Child(Parent):
+            __slots__ = ('b',)
+
+            def __init__(self, a, b):
+                self.a, self.b = a, b
+
+        self.check_raises(
+            Child(1, 'x'),
+            Child(2, 'x'),
+            'Child not as expected:\n'
+            '\n'
+            'attributes same:\n'
+            "['b']\n"
+            '\n'
+            'attributes differ:\n'
+            "'a': 1 != 2"
+        )
+
+    def test_empty_child_slots(self):
+
+        class Parent(object):
+            __slots__ = ('a',)
+
+            def __init__(self, a):
+                self.a = a
+
+        class Child(Parent):
+            __slots__ = ()
+
+        compare(Child(1), Child(1))
+
+
+class TestIgnore(CompareHelper):
+
+    class Parent(object):
+        def __init__(self, id):
+            self.id = id
+        def __repr__(self):
+            return '<{}:{}>'.format(type(self).__name__, self.id)
+
+    class Child(Parent): pass
+
+    def test_ignore_attributes(self):
+        compare(self.Parent(1), self.Parent(2), ignore_attributes={'id'})
+
+    def test_ignore_attributes_different_types(self):
+        self.check_raises(
+            self.Parent(1),
+            self.Child(2),
+            '<Parent:1> != <Child:2>',
+            ignore_attributes={'id'}
+        )
+
+    def test_ignore_attributes_per_type(self):
+        ignore = {self.Parent: {'id'}}
+        compare(self.Parent(1), self.Parent(2), ignore_attributes=ignore)
+        self.check_raises(
+            self.Child(1),
+            self.Child(2),
+            'Child not as expected:\n'
+            '\n'
+            'attributes differ:\n'
+            "'id': 1 != 2",
+            ignore_attributes=ignore
+        )
