@@ -1,9 +1,14 @@
-from testfixtures import (
-    log_capture, compare, Comparison as C, LogCapture, ShouldRaise
-)
-from unittest import TestCase
+from __future__ import absolute_import
 
 from logging import getLogger
+from unittest import TestCase
+
+from testfixtures.shouldraise import ShouldAssert
+from testfixtures.mock import patch
+
+from testfixtures import (
+    log_capture, compare, Comparison as C, LogCapture
+)
 
 root = getLogger()
 one = getLogger('one')
@@ -176,10 +181,7 @@ class TestLog_Capture(TestCase):
         with LogCapture() as log:
             getLogger().info('oh hai')
 
-        with ShouldRaise(AssertionError) as s:
-            log.check(('root', 'INFO', 'oh noez'))
-
-        compare(str(s.raised), expected=(
+        with ShouldAssert(
             "sequence not as expected:\n\n"
             "same:\n"
             "()\n\n"
@@ -187,17 +189,15 @@ class TestLog_Capture(TestCase):
             "(('root', 'INFO', 'oh noez'),)\n\n"
             "actual:\n"
             "(('root', 'INFO', 'oh hai'),)"
-        ))
+        ):
+            log.check(('root', 'INFO', 'oh noez'))
 
     def test_recursive_check(self):
 
         with LogCapture(recursive_check=True) as log:
             getLogger().info('oh hai')
 
-        with ShouldRaise(AssertionError) as s:
-            log.check(('root', 'INFO', 'oh noez'))
-
-        compare(str(s.raised), expected=(
+        with ShouldAssert(
             "sequence not as expected:\n\n"
             "same:\n()\n\n"
             "expected:\n(('root', 'INFO', 'oh noez'),)\n\n"
@@ -209,7 +209,20 @@ class TestLog_Capture(TestCase):
             "actual:\n"
             "('oh hai',)\n\n"
             "While comparing [0][2]: 'oh noez' (expected) != 'oh hai' (actual)"
-        ))
+        ):
+            log.check(('root', 'INFO', 'oh noez'))
+
+    @log_capture()
+    @patch('testfixtures.tests.sample1.SampleClassA')
+    def test_patch_then_log(self, a1, a2):
+        actual = [type(c).__name__ for c in (a1, a2)]
+        compare(actual, expected=['MagicMock', 'LogCaptureForDecorator'])
+
+    @patch('testfixtures.tests.sample1.SampleClassA')
+    @log_capture()
+    def test_log_then_patch(self, a1, a2):
+        actual = [type(c).__name__ for c in (a1, a2)]
+        compare(actual, expected=['LogCaptureForDecorator', 'MagicMock'])
 
 
 class BaseCaptureTest(TestCase):
